@@ -20,8 +20,8 @@ def random_alphanumeric(length):
     return ''.join(r.choice(string.ascii_uppercase + string.ascii_lowercase + string.digits) for x in range(length))
 
 def random_digits(num):
-    string = ("%0" + str(num) + "d") % int(random.random()*math.pow(10, int(num)))
-    return string[0:int(num)]
+    the_string = ("%0" + str(num) + "d") % int(random.random()*math.pow(10, int(num)))
+    return the_string[0:int(num)]
 
 if __name__ == "__main__":
     sys.stdout.write(random_string(32))
