@@ -1,6 +1,6 @@
 import docassemble.base.parse
 
-cache = dict()
+cache = {}
 
 def get_interview(path):
     if path is None:
@@ -14,7 +14,7 @@ def get_interview(path):
         the_interview = interview_source.get_interview()
         the_interview.from_cache = False
         cache[interview_source.path] = {'index': interview_source.get_index(), 'interview': the_interview, 'source': interview_source}
-    return(the_interview)
+    return the_interview
 
 def clear_cache(path):
     if path in cache:
